Annotation class abstract

Base class for all annotation types

Implementers

Constructors

Annotation({required String id, required AnnotationType type, required int pageNumber, required DateTime createdAt, required DateTime modifiedAt})
const

Properties

createdAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
modifiedAt DateTime
final
pageNumber int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AnnotationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert annotation to JSON
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) Annotation
Create annotation from JSON