DrawingAnnotation class

Annotation for freehand drawing paths

Inheritance

Constructors

DrawingAnnotation({required String id, required int pageNumber, required DateTime createdAt, required DateTime modifiedAt, required List<Offset> path, required Color color, required double strokeWidth, StrokeCap strokeCap = StrokeCap.round})
const

Properties

color Color
final
createdAt DateTime
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
modifiedAt DateTime
finalinherited
pageNumber int
finalinherited
path List<Offset>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeCap StrokeCap
final
strokeWidth double
final
type AnnotationType
finalinherited

Methods

copyWith({String? id, int? pageNumber, DateTime? createdAt, DateTime? modifiedAt, List<Offset>? path, Color? color, double? strokeWidth, StrokeCap? strokeCap}) DrawingAnnotation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert annotation to JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) DrawingAnnotation
Create annotation from JSON
override