HighlightAnnotation class

Annotation for highlights (text selection areas)

Inheritance

Constructors

HighlightAnnotation({required String id, required int pageNumber, required DateTime createdAt, required DateTime modifiedAt, required List<Rect> boundingBoxes, Color color = const Color(0xFFFFFF00), double opacity = 0.3})
const

Properties

boundingBoxes List<Rect>
final
color Color
final
createdAt DateTime
finalinherited
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
modifiedAt DateTime
finalinherited
opacity double
final
pageNumber int
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type AnnotationType
finalinherited

Methods

copyWith({String? id, int? pageNumber, DateTime? createdAt, DateTime? modifiedAt, List<Rect>? boundingBoxes, Color? color, double? opacity}) HighlightAnnotation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert annotation to JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) HighlightAnnotation
Create annotation from JSON
override