NoteAnnotation class

Annotation for text notes

Inheritance

Constructors

NoteAnnotation({required String id, required int pageNumber, required DateTime createdAt, required DateTime modifiedAt, required Offset position, required String text, Color backgroundColor = const Color(0xFFFFFF99), Color textColor = const Color(0xFF000000), double fontSize = 14.0})
const

Properties

backgroundColor Color
final
createdAt DateTime
finalinherited
fontSize double
final
hashCode int
The hash code for this object.
no setterinherited
id String
finalinherited
modifiedAt DateTime
finalinherited
pageNumber int
finalinherited
position Offset
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
final
textColor Color
final
type AnnotationType
finalinherited

Methods

copyWith({String? id, int? pageNumber, DateTime? createdAt, DateTime? modifiedAt, Offset? position, String? text, Color? backgroundColor, Color? textColor, double? fontSize}) NoteAnnotation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Convert annotation to JSON
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromJson(Map<String, dynamic> json) NoteAnnotation
Create annotation from JSON
override