AnnotationMode enum

Different annotation modes the user can be in

Inheritance
Available extensions

Values

view → const AnnotationMode
draw → const AnnotationMode
note → const AnnotationMode
shape → const AnnotationMode
highlight → const AnnotationMode
select → const AnnotationMode

Properties

displayName String

Available on AnnotationMode, provided by the AnnotationModeExtension extension

no setter
hashCode int
The hash code for this object.
no setterinherited
icon IconData

Available on AnnotationMode, provided by the AnnotationModeExtension extension

no setter
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tooltip String

Available on AnnotationMode, provided by the AnnotationModeExtension extension

no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnnotationMode>
A constant List of the values in this enum, in order of their declaration.