AnnotationOverlay class

Overlay widget that handles annotation rendering and gesture detection

Inheritance

Constructors

AnnotationOverlay({Key? key, required int pageNumber, required List<Annotation> annotations, required AnnotationMode currentMode, required Color currentColor, required double currentStrokeWidth, required ShapeType currentShapeType, required void onAnnotationAdded(Annotation), required void onAnnotationUpdated(Annotation), required void onAnnotationRemoved(String, int), required Size pageSize, double scaleX = 1.0, double scaleY = 1.0})
const

Properties

annotations List<Annotation>
final
currentColor Color
final
currentMode AnnotationMode
final
currentShapeType ShapeType
final
currentStrokeWidth double
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onAnnotationAdded → void Function(Annotation)
final
onAnnotationRemoved → void Function(String, int)
final
onAnnotationUpdated → void Function(Annotation)
final
pageNumber int
final
pageSize Size
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scaleX double
final
scaleY double
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<AnnotationOverlay>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited