NoteAnnotation class
Annotation for text notes
- Inheritance
-
- Object
- Annotation
- NoteAnnotation
Constructors
Properties
- backgroundColor → Color
-
final
- createdAt → DateTime
-
finalinherited
- fontSize → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- modifiedAt → DateTime
-
finalinherited
- pageNumber → int
-
finalinherited
- position → Offset
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String
-
final
- textColor → Color
-
final
- type → AnnotationType
-
finalinherited
Methods
-
copyWith(
{String? id, int? pageNumber, DateTime? createdAt, DateTime? modifiedAt, Offset? position, String? text, Color? backgroundColor, Color? textColor, double? fontSize}) → NoteAnnotation -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert annotation to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → NoteAnnotation -
Create annotation from JSON
override