ShapeAnnotation class
Annotation for geometric shapes
- Inheritance
-
- Object
- Annotation
- ShapeAnnotation
Constructors
Properties
- bounds → Rect
-
final
- color → Color
-
final
- createdAt → DateTime
-
finalinherited
- fillColor → Color?
-
final
- filled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
finalinherited
- modifiedAt → DateTime
-
finalinherited
- pageNumber → int
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeType → ShapeType
-
final
- strokeWidth → double
-
final
- type → AnnotationType
-
finalinherited
Methods
-
copyWith(
{String? id, int? pageNumber, DateTime? createdAt, DateTime? modifiedAt, ShapeType? shapeType, Rect? bounds, Color? color, double? strokeWidth, bool? filled, Color? fillColor}) → ShapeAnnotation -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Convert annotation to JSON
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromJson(
Map< String, dynamic> json) → ShapeAnnotation -
Create annotation from JSON
override