AnnotationStorage class
Service for storing and retrieving annotations as JSON
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearAnnotations(
) → Future< void> - Delete all stored annotations
-
exportAnnotations(
Map< int, List< annotations, String filePath) → Future<Annotation> >void> - Export annotations to a custom file path
-
getStoredAnnotationsSize(
) → Future< int> - Get the size of stored annotations file in bytes
-
hasStoredAnnotations(
) → Future< bool> - Check if annotations file exists
-
importAnnotations(
String filePath) → Future< Map< int, List< >Annotation> > - Import annotations from a custom file path
-
loadAnnotations(
) → Future< Map< int, List< ?>Annotation> > - Load annotations from local storage
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveAnnotations(
Map< int, List< annotations) → Future<Annotation> >void> - Save annotations to local storage
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited